@@ -1,16 +1,29 @@
 # -*- coding: utf-8 -*-
 #------------------------------------------------------------------------------
 # file: $Id$
-# auth: metagriffin <metagriffin@uberdev.org>
+# auth: metagriffin <mg.github@metagriffin.net>
 # date: 2009/09/11
-# copy: (C) CopyLoose 2009 UberDev <hardcore@uberdev.org>, No Rights Reserved.
+# copy: (C) Copyright 2009-EOT metagriffin -- see LICENSE.txt
+#------------------------------------------------------------------------------
+# This software is free software: you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This software is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see http://www.gnu.org/licenses/.
 #------------------------------------------------------------------------------
 
 # IMPORTANT NOTE: in these routines, i am purposefully not doing a
 # shutil.rmtree() when doing a `os.rmdir()` so that the presence of
 # any unexpected files will cause an exception.
 
-import sys, os, unittest, tempfile, stat, shutil
+import sys, os, unittest, tempfile, stat, shutil, uuid
 
 from .filesystemoverlay import FileSystemOverlay
 
@@ -474,6 +487,61 @@ class TestFileSystemOverlay(unittest.TestCase):
     os.rmdir(os.path.join(tdir, 'a'))
     os.rmdir(tdir)
 
+  #----------------------------------------------------------------------------
+  def test_tempfile_mktemp(self):
+    with FileSystemOverlay() as fso:
+      fname = tempfile.mktemp(prefix='fso-test_filesystemoverlay-unittest.mktemp.')
+      with open(fname, 'wb') as fp:
+        fp.write('fname: ' + fname + '\n')
+    self.assertFalse(os.path.exists(fname))
+
+  #----------------------------------------------------------------------------
+  def test_tempfile_mkstemp(self):
+    with FileSystemOverlay() as fso:
+      fd, fname = tempfile.mkstemp(prefix='fso-test_filesystemoverlay-unittest.mkstemp.')
+      with os.fdopen(fd, 'wb') as fp:
+        fp.write('fname: ' + fname + '\n')
+    self.assertFalse(os.path.exists(fname))
+
+  #----------------------------------------------------------------------------
+  def test_os_open(self):
+    fname = '/tmp/fso-unittest.osopen-' + str(uuid.uuid4()) + '.tmp'
+    with FileSystemOverlay() as fso:
+      fd = os.open(fname, os.O_CREAT|os.O_WRONLY, 0644)
+      os.write(fd, 'osopen.test\n')
+      os.close(fd)
+      with open(fname, 'rb') as fp:
+        self.assertEqual(fp.read(), 'osopen.test\n')
+      self.assertTrue(os.path.exists(fname))
+    self.assertFalse(os.path.exists(fname))
+
+  #----------------------------------------------------------------------------
+  def test_passthru_mktemp(self):
+    with FileSystemOverlay(passthru='.*fso-unittest\\.passthru\\.keep\\..*') as fso:
+      fkeep = tempfile.mktemp(prefix='fso-unittest.passthru.keep.')
+      fdrop = tempfile.mktemp(prefix='fso-unittest.passthru.drop.')
+      with open(fkeep, 'wb') as fp:
+        fp.write('keep')
+      with open(fdrop, 'wb') as fp:
+        fp.write('drop')
+    self.assertFalse(os.path.exists(fdrop))
+    self.assertTrue(os.path.exists(fkeep))
+    self.assertEqual(open(fkeep, 'rb').read(), 'keep')
+
+  #----------------------------------------------------------------------------
+  def test_passthru_mkstemp(self):
+    with FileSystemOverlay(passthru='.*fso-unittest\\.passthru\\.keep\\..*') as fso:
+      kfd, fkeep = tempfile.mkstemp(prefix='fso-unittest.passthru.keep.')
+      dfd, fdrop = tempfile.mkstemp(prefix='fso-unittest.passthru.drop.')
+      with os.fdopen(kfd, 'wb') as fp:
+        fp.write('keep')
+      with os.fdopen(dfd, 'wb') as fp:
+        fp.write('drop')
+    self.assertFalse(os.path.exists(fdrop))
+    self.assertTrue(os.path.exists(fkeep))
+    self.assertEqual(open(fkeep, 'rb').read(), 'keep')
+
+
 #------------------------------------------------------------------------------
 # end of $Id$
 #------------------------------------------------------------------------------
